@@ -1,41 +1,66 @@
 import os
 from typing import Optional
+
 import typer
 
-from publicator import git, github, poetry
+import publicator
+from publicator import config, git, github, poetry
 from publicator.semver import Semver
 
 preview = os.environ.get("PUBLICATOR_PREVIEW")
+configuration = config.factory()
+app = typer.Typer(name=publicator.name)
 
-app = typer.Typer(name="publicator")
+
+def version_callback(value: bool) -> None:
+    if not value:
+        return
+
+    typer.secho(f"🦄 {publicator.version()}", fg=typer.colors.BRIGHT_BLUE, bold=True)
+    raise typer.Exit()
 
 
 @app.command()
 def cli(
-    version: str = typer.Argument(
+    bump: str = typer.Argument(
         ...,
         metavar="version",
         help="can be a valid semver or one of: patch, minor, major, prepatch, preminor, premajor, prerelease",
     ),
+    version: Optional[bool] = typer.Option(None, "--version", "-V", callback=version_callback, is_eager=True),
     repository: Optional[str] = typer.Option(
-        default=None, metavar="name", help="Custom repository for publishing (must be specified in pyproject.toml)"
+        default=configuration.get("repository"),
+        metavar="name",
+        help="Custom repository for publishing (must be specified in pyproject.toml)",
     ),
-    any_branch: bool = typer.Option(default=False, help="Allow publishing from any branch"),
-    clean: bool = typer.Option(default=True, help="Ensure you're working with the latest changes"),
-    tag: bool = typer.Option(default=True, help="Create a new tag for Git"),
-    publish: bool = typer.Option(default=True, help="Publish the package to the registry"),
-    push: bool = typer.Option(default=True, help="Push commits and tags to Git"),
+    any_branch: bool = typer.Option(
+        default=configuration.get("any-branch", False), help="Allow publishing from any branch"
+    ),
+    clean: bool = typer.Option(
+        default=configuration.get("clean", True), help="Ensure you're working with the latest changes"
+    ),
+    tag: bool = typer.Option(default=configuration.get("tag", True), help="Create a new tag for Git"),
+    publish: bool = typer.Option(
+        default=configuration.get("publish", True), help="Publish the package to the registry"
+    ),
+    push: bool = typer.Option(default=configuration.get("push", True), help="Push commits and tags to Git"),
     test_script: str = typer.Option(
-        default="pytest", help="Name of the test script to run under the current virtual environment"
+        default=configuration.get("test-script", "pytest -x --assert=plain"),
+        help="Name of the test script to run under the current virtual environment",
     ),
     template: str = typer.Option(
-        default="release: %s", help="Commit message template (`%s` will be replaced with the new version tag)"
+        default=configuration.get("template", "release: %s"),
+        help="Commit message template (`%s` will be replaced with the new version tag)",
     ),
     release_draft: bool = typer.Option(
-        default=True,
+        default=configuration.get("release-draft", True),
         help="Opens a pre-filled GitHub release page with browser if the current project is hosted on GitHub",
     ),
 ) -> None:
+    """
+    Handles publishing a new Python package via Poetry safely and conveniently.
+    """
+
     if not any_branch:
         verify_branch()
 
@@ -43,17 +68,17 @@ def cli(
         clean_up()
         install_dependencies()
 
-    run_tests(test_script)
+    if test_script:
+        run_tests(test_script)
 
-    new_version = bump_version(version)
+    new_version = bump_version(bump)
     commit_changes(new_version, template)
 
     if tag:
         create_tag(new_version)
 
-    build_package()
-
     if publish:
+        build_package()
         publish_package(repository)
 
     if push:
